%
% ===> plotpol.m
%
% Program to plot approximation of optimal policy function for paper
% "Learning and Control in a Changing Economic Environment" (Beck and Wieland,
% JEDC, 2002, 1359-1377).
%
% Input: 	Needs ASCII file onetv.pol that contains optimal policy function,
%		 	evaluated at grid points. Assumes that onetv.pol is in the same
%		 	directory as plotpol.m.
%
% Output:	Plots figures 1 to 6 of paper.
%
% Program written by Volker Wieland
%
% Last change 03/04/2003.
%


% Specifying flag variables for use of colors and generating .eps file

colo = 1;

% colo = 0: figures are black/white,
% colo = 1: figures are in color

printgraph = 0;

% printgraph = 0: no .eps file is generated
% printgraph = 1: .eps file is generated (and saved in default directory)


% Initializing grid for state variables 

b=[-5 -3 -2 -1.8 -1.6 -1.4 -1.2 -1.0 -0.8 -0.6 -0.4 -0.2 -0.005 ...
   0.005 0.2 0.4 0.6 0.8 1.0 1.2 1.4 1.6 1.8 2.0 3.0 5.0]';
[nb,junk]=size(b);

vb= [0.0001 0.0025 0.01 0.0225 0.04 0.0625 0.09 0.1225 0.16 0.2025 ...
      0.25 0.3025 0.36 0.4225 0.49 0.5625 0.64 0.7225 0.81 0.9025 1]';
[nvb,junk]=size(vb);

ylag=[-5 -3 -2 -1.8 -1.6 -1.4 -1.2 -1.0 -0.8 -0.6 -0.4 -0.2 -0.0001 ...
   0.0001 0.2 0.4 0.6 0.8 1.0 1.2 1.4 1.6 1.8 2.0 3.0 5.0]';
[ny,junk]=size(ylag);

[B,VB,YLAG]=ndgrid(b,vb,ylag);



% Initializing some other parameter values

rho=1;
sigmaeta=0;



% Load data from onetv.pol 

load onetv.pol;

optpol=zeros(nb,nvb,ny);
myopol=zeros(nb,nvb,ny);
certpol=zeros(nb,nvb,ny);

count=0;
for ib=1:1:nb;
  for ivb=1:1:nvb;
    for iy=1:1:ny;
      count=count+1;
      optpol(ib,ivb,iy)=onetv(count);
    end;
  end;
end;
clear onetv;



% Compute certainty equivalent and myopic policy funtions 

certpol= -YLAG.*rho./B;
myopol=-YLAG.*rho.*(B./(B.^2+(VB+sigmaeta)));



% Specifying grid points for which optimal policy is plotted

bsh=[12 11 10 9]';
vbsh=[5 7 11 15]';
[nbsh,junk]=size(bsh);
[nvbsh,junk]=size(vbsh);
 


% Plot figure 1 of paper

for row=2:1:2;
  for col=3:1:3;
    jb=bsh(row);
    jvb=vbsh(col);
    pan=(row-1)*nvbsh+col;
    subplot(1,1,1);
    showopt=squeeze(optpol(jb,jvb,:));
    showcert=squeeze(certpol(jb,jvb,:));
    showmyo=squeeze(myopol(jb,jvb,:));

    if colo == 0
      plot(ylag,showopt,ylag,showopt,'.',ylag,...
      showcert,'-',ylag,showmyo,'--',ylag,0.*showmyo,'color','k');
    elseif colo == 1
      plot(ylag,showopt,ylag,showopt,'.',ylag,...
      showcert,'-',ylag,showmyo,'--',ylag,0.*showmyo);
    end

    axis([-3 3 -8 8]);
    text('string','SD(b) = 0.2','unit','centimeters','position',[-1.5,11],'fontsize',10);
    text('string','State Variable x','unit','centimeters','position',[14,-0.5],'fontsize',12);
    text('string','Control Variable u','unit','centimeters','position',[-1.5,13],'fontsize',12);
	text('string','optimal','unit','centimeters','position',[7,7.3],'fontsize',10);
	text('string','cautionary','unit','centimeters','position',[13,7.3],'fontsize',10);
	text('string','certainty-equivalent','unit','centimeters','position',[1.7,2.1],'fontsize',10);

    if colo == 0 & printgraph == 1;
      outfile = 'figure1bw.eps';
	  print('-deps2',outfile);
    elseif colo == 1 & printgraph == 1;
      outfile = 'figure1c.eps';
	  print('-depsc2',outfile);
    end

  end

end
  
pause;

for row=1:1:nbsh;
  for col=1:1:nvbsh;
    jb=bsh(row);
    jvb=vbsh(col);
    pan=(row-1)*nvbsh+col;
    subplot(nbsh,nvbsh,pan);
    showopt=squeeze(optpol(jb,jvb,:));
    showcert=squeeze(certpol(jb,jvb,:));
    showmyo=squeeze(myopol(jb,jvb,:));
     
    if colo == 0
      plot(ylag,showopt,'-',ylag,showopt,'.',ylag,...
      showcert,'-',ylag,showmyo,'-',ylag,0.*showmyo,'-','color','k','MarkerSize',4.7);
    elseif colo == 1
      plot(ylag,showopt,'-',ylag,showopt,'.',ylag,...
      showcert,'-',ylag,showmyo,'-',ylag,0.*showmyo,'-','MarkerSize',4.7);
    end
    axis([-2 2 -8 8]);
    if col > 1
      set(gca, 'ytick',[]);
    else
      set(gca, 'ytick',[  -6 -3 0 3  6 ]);
      text('string','Control Variable u','unit','centimeters','position',[-0.9,2.7],'fontsize',7);
      if row == 1
        ylabel('b = -0.2');   
      end
      if row == 2
        ylabel('b = -0.3');   
      end
      if row == 3
        ylabel('b = -0.5');   
      end
      if row == 4
        ylabel('b = -0.7');   
      end
    end
    if row < nbsh
      set(gca, 'xtick',[]);
      if row == 1
        if col == 1
		  text('string','SD(b) = 0.2','unit','centimeters','position',[0.7,3.1],'fontsize',10);
        end
        if col == 2
		  text('string','SD(b) = 0.3','unit','centimeters','position',[0.7,3.1],'fontsize',10);
        end
        if col == 3
		  text('string','SD(b) = 0.5','unit','centimeters','position',[0.7,3.1],'fontsize',10);
		  text('string','optimal','unit','centimeters','position',[2.7,2.1],'fontsize',7);
		  text('string','cautionary','unit','centimeters','position',[1.9,1.1],'fontsize',7);
		  text('string','certainty-equivalent','unit','centimeters','position',[0.9,0.2],'fontsize',7);
        end
        if col == 4
		  text('string','SD(b) = 0.7','unit','centimeters','position',[0.7,3.1],'fontsize',10);
        end
      end
    else
      set(gca, 'xtick',[-2 0 2]);
      text('string','State Variable x','unit','centimeters','position',[2.3,-0.7],'fontsize',7);
    end
  end
end


% Output Filename 

if colo == 0 & printgraph == 1;
   outfile = 'figure2bw.eps';
   print('-deps',outfile);
elseif colo == 1 & printgraph == 1;
  outfile = 'figure2c.eps';
  print('-depsc',outfile);
end 


'End of Program'
